Learn R Programming

tibbrConnector (version 1.5.1)

tibbr.user: Search tibbr For Users

Description

Searches tibbr for users.

Usage

tibbr.user(connection, user = NULL)

Arguments

connection
a tibbrConnection object indicating the tibbr instance to search.
user
a character string containing the search criteria. If NULL, tibbr returns all users on the tibbr instance. (Note: This can take a long time to return, depending on the number of users on your tibbr instance.) tibbr searches the following fields for matches:
  • First name
  • Last name
  • Email address
  • Login name
  • Department
  • Location
  • Profile description

Value

returns a list of tibbrUser objects describing the results of the search. The names of the tibbrUser objects represent fields of the corresponding user's profile in tibbr.

Details

Errors encountered during the search process are raised by this function.

See Also

tibbr.subject

Examples

Run this code
## Not run: 
# con <- tibbr.connect("try.tibbr.com", "myusername", "mypassword")
# users <- tibbr.user(con, "Sam")
# users
# ## End(Not run)

Run the code above in your browser using DataLab