a tibbrConnection object indicating the tibbr instance to search.
subject
a character string containing the search criteria. If NULL, tibbr
returns all subjects on the tibbr instance. (Note: This can
take a long time to return, depending on the number of subjects on your
tibbr instance.)
tibbr searchs the following fields for matches:
Subject name
Subject display name
Subject description
Value
returns a list of tibbrSubject objects describing the results of the
search. The names of the tibbrSubject objects represent attributes
of the corresponding subject in tibbr.
Details
Errors encountered during the search process are raised by this function.